
****************
Utility routines
****************

.. todo::

   This section needs looking at.

There are a number of utility routines provided by Sherpa that may
be useful. Should they be documented here or elsewhere?

Unfortunately it is not always obvious whether a routine is for use
with the Object-Oriented API or the Session API.

Reference/API
=============

.. toctree::
   :maxdepth: 2

   sherpa
   err
   utils
   testing
   io
   astro_io
